import { N as NOOP_MIDDLEWARE_FN } from './chunks/astro-designed-error-pages_BILOX3dh.mjs';
import { l as decodeKey } from './chunks/astro/server_DwSm4QoH.mjs';

function sanitizeParams(params) {
  return Object.fromEntries(
    Object.entries(params).map(([key, value]) => {
      if (typeof value === "string") {
        return [key, value.normalize().replace(/#/g, "%23").replace(/\?/g, "%3F")];
      }
      return [key, value];
    })
  );
}
function getParameter(part, params) {
  if (part.spread) {
    return params[part.content.slice(3)] || "";
  }
  if (part.dynamic) {
    if (!params[part.content]) {
      throw new TypeError(`Missing parameter: ${part.content}`);
    }
    return params[part.content];
  }
  return part.content.normalize().replace(/\?/g, "%3F").replace(/#/g, "%23").replace(/%5B/g, "[").replace(/%5D/g, "]");
}
function getSegment(segment, params) {
  const segmentPath = segment.map((part) => getParameter(part, params)).join("");
  return segmentPath ? "/" + segmentPath : "";
}
function getRouteGenerator(segments, addTrailingSlash) {
  return (params) => {
    const sanitizedParams = sanitizeParams(params);
    let trailing = "";
    if (addTrailingSlash === "always" && segments.length) {
      trailing = "/";
    }
    const path = segments.map((segment) => getSegment(segment, sanitizedParams)).join("") + trailing;
    return path || "/";
  };
}

function deserializeRouteData(rawRouteData) {
  return {
    route: rawRouteData.route,
    type: rawRouteData.type,
    pattern: new RegExp(rawRouteData.pattern),
    params: rawRouteData.params,
    component: rawRouteData.component,
    generate: getRouteGenerator(rawRouteData.segments, rawRouteData._meta.trailingSlash),
    pathname: rawRouteData.pathname || void 0,
    segments: rawRouteData.segments,
    prerender: rawRouteData.prerender,
    redirect: rawRouteData.redirect,
    redirectRoute: rawRouteData.redirectRoute ? deserializeRouteData(rawRouteData.redirectRoute) : void 0,
    fallbackRoutes: rawRouteData.fallbackRoutes.map((fallback) => {
      return deserializeRouteData(fallback);
    }),
    isIndex: rawRouteData.isIndex,
    origin: rawRouteData.origin
  };
}

function deserializeManifest(serializedManifest) {
  const routes = [];
  for (const serializedRoute of serializedManifest.routes) {
    routes.push({
      ...serializedRoute,
      routeData: deserializeRouteData(serializedRoute.routeData)
    });
    const route = serializedRoute;
    route.routeData = deserializeRouteData(serializedRoute.routeData);
  }
  const assets = new Set(serializedManifest.assets);
  const componentMetadata = new Map(serializedManifest.componentMetadata);
  const inlinedScripts = new Map(serializedManifest.inlinedScripts);
  const clientDirectives = new Map(serializedManifest.clientDirectives);
  const serverIslandNameMap = new Map(serializedManifest.serverIslandNameMap);
  const key = decodeKey(serializedManifest.key);
  return {
    // in case user middleware exists, this no-op middleware will be reassigned (see plugin-ssr.ts)
    middleware() {
      return { onRequest: NOOP_MIDDLEWARE_FN };
    },
    ...serializedManifest,
    assets,
    componentMetadata,
    inlinedScripts,
    clientDirectives,
    routes,
    serverIslandNameMap,
    key
  };
}

const manifest = deserializeManifest({"hrefRoot":"file:///Users/khamudom/Repos/Camden/ufcw152/","adapterName":"@astrojs/node","routes":[{"file":"","links":[],"scripts":[],"styles":[],"routeData":{"type":"page","component":"_server-islands.astro","params":["name"],"segments":[[{"content":"_server-islands","dynamic":false,"spread":false}],[{"content":"name","dynamic":true,"spread":false}]],"pattern":"^\\/_server-islands\\/([^/]+?)\\/?$","prerender":false,"isIndex":false,"fallbackRoutes":[],"route":"/_server-islands/[name]","origin":"internal","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[{"type":"inline","content":"[data-astro-image]{width:100%;height:auto;object-fit:var(--fit);object-position:var(--pos);aspect-ratio:var(--w) / var(--h)}[data-astro-image=responsive]{max-width:calc(var(--w) * 1px);max-height:calc(var(--h) * 1px)}[data-astro-image=fixed]{width:calc(var(--w) * 1px);height:calc(var(--h) * 1px)}\n"}],"routeData":{"type":"endpoint","isIndex":false,"route":"/_image","pattern":"^\\/_image\\/?$","segments":[[{"content":"_image","dynamic":false,"spread":false}]],"params":[],"component":"node_modules/astro/dist/assets/endpoint/generic.js","pathname":"/_image","prerender":false,"fallbackRoutes":[],"origin":"internal","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[],"routeData":{"route":"/404","isIndex":false,"type":"page","pattern":"^\\/404\\/?$","segments":[[{"content":"404","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/404.astro","pathname":"/404","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[{"type":"inline","content":".breadcrumb[data-astro-cid-qaanghzh]{padding:1rem;background-color:var(--light-gray);margin-bottom:2rem}.breadcrumb[data-astro-cid-qaanghzh] ol[data-astro-cid-qaanghzh]{list-style:none;display:flex;flex-wrap:wrap;gap:.5rem;max-width:var(--max-width);margin:0 auto}.breadcrumb[data-astro-cid-qaanghzh] li[data-astro-cid-qaanghzh]{display:flex;align-items:center;gap:.5rem}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]{color:var(--primary-color);text-decoration:none}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]:hover{text-decoration:underline}.separator[data-astro-cid-qaanghzh]{color:#666}\nli[data-astro-cid-jiisrvlr]{position:relative}a[data-astro-cid-jiisrvlr]{color:#fff;text-decoration:none;font-weight:700;transition:color .3s}a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}.has-dropdown[data-astro-cid-jiisrvlr]>.dropdown[data-astro-cid-jiisrvlr]{display:none;position:absolute;top:100%;left:0;background-color:#fff;border-radius:4px;box-shadow:0 2px 5px #0003;min-width:200px;z-index:1000}.has-dropdown[data-astro-cid-jiisrvlr]:hover>.dropdown[data-astro-cid-jiisrvlr]{display:block}.dropdown[data-astro-cid-jiisrvlr] li[data-astro-cid-jiisrvlr]{padding:.5rem 1rem}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]{color:var(--primary-color);display:block;padding:.5rem 0}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}@media (max-width: 768px){.dropdown[data-astro-cid-jiisrvlr]{position:static;box-shadow:none;margin-top:.5rem}}.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{display:flex;list-style:none;gap:2rem}@media (max-width: 768px){.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{flex-direction:column;text-align:center;gap:1rem}}\n"}],"routeData":{"route":"/about/staff","isIndex":false,"type":"page","pattern":"^\\/about\\/staff\\/?$","segments":[[{"content":"about","dynamic":false,"spread":false}],[{"content":"staff","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/about/staff.astro","pathname":"/about/staff","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[{"type":"inline","content":".breadcrumb[data-astro-cid-qaanghzh]{padding:1rem;background-color:var(--light-gray);margin-bottom:2rem}.breadcrumb[data-astro-cid-qaanghzh] ol[data-astro-cid-qaanghzh]{list-style:none;display:flex;flex-wrap:wrap;gap:.5rem;max-width:var(--max-width);margin:0 auto}.breadcrumb[data-astro-cid-qaanghzh] li[data-astro-cid-qaanghzh]{display:flex;align-items:center;gap:.5rem}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]{color:var(--primary-color);text-decoration:none}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]:hover{text-decoration:underline}.separator[data-astro-cid-qaanghzh]{color:#666}\nli[data-astro-cid-jiisrvlr]{position:relative}a[data-astro-cid-jiisrvlr]{color:#fff;text-decoration:none;font-weight:700;transition:color .3s}a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}.has-dropdown[data-astro-cid-jiisrvlr]>.dropdown[data-astro-cid-jiisrvlr]{display:none;position:absolute;top:100%;left:0;background-color:#fff;border-radius:4px;box-shadow:0 2px 5px #0003;min-width:200px;z-index:1000}.has-dropdown[data-astro-cid-jiisrvlr]:hover>.dropdown[data-astro-cid-jiisrvlr]{display:block}.dropdown[data-astro-cid-jiisrvlr] li[data-astro-cid-jiisrvlr]{padding:.5rem 1rem}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]{color:var(--primary-color);display:block;padding:.5rem 0}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}@media (max-width: 768px){.dropdown[data-astro-cid-jiisrvlr]{position:static;box-shadow:none;margin-top:.5rem}}.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{display:flex;list-style:none;gap:2rem}@media (max-width: 768px){.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{flex-direction:column;text-align:center;gap:1rem}}\n"}],"routeData":{"route":"/about","isIndex":true,"type":"page","pattern":"^\\/about\\/?$","segments":[[{"content":"about","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/about/index.astro","pathname":"/about","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[],"routeData":{"route":"/blog/backup-slug","isIndex":false,"type":"page","pattern":"^\\/blog\\/backup-slug\\/?$","segments":[[{"content":"blog","dynamic":false,"spread":false}],[{"content":"backup-slug","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/blog/backup-slug.astro","pathname":"/blog/backup-slug","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[{"type":"inline","content":".breadcrumb[data-astro-cid-qaanghzh]{padding:1rem;background-color:var(--light-gray);margin-bottom:2rem}.breadcrumb[data-astro-cid-qaanghzh] ol[data-astro-cid-qaanghzh]{list-style:none;display:flex;flex-wrap:wrap;gap:.5rem;max-width:var(--max-width);margin:0 auto}.breadcrumb[data-astro-cid-qaanghzh] li[data-astro-cid-qaanghzh]{display:flex;align-items:center;gap:.5rem}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]{color:var(--primary-color);text-decoration:none}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]:hover{text-decoration:underline}.separator[data-astro-cid-qaanghzh]{color:#666}\n.discount-grid[data-astro-cid-qbm6zaax]{display:grid;grid-template-columns:repeat(auto-fit,minmax(250px,1fr));gap:2rem;margin-top:2rem}.discount-card[data-astro-cid-qbm6zaax]{background-color:var(--light-gray);padding:2rem;border-radius:5px}.discount-card[data-astro-cid-qbm6zaax] h2[data-astro-cid-qbm6zaax]{color:var(--primary-color);margin-bottom:1rem}.discount-card[data-astro-cid-qbm6zaax] ul[data-astro-cid-qbm6zaax]{list-style:none}.discount-card[data-astro-cid-qbm6zaax] li[data-astro-cid-qbm6zaax]{margin-bottom:.5rem;padding-left:1.5rem;position:relative}.discount-card[data-astro-cid-qbm6zaax] li[data-astro-cid-qbm6zaax]:before{content:\"•\";color:var(--secondary-color);position:absolute;left:0}\nli[data-astro-cid-jiisrvlr]{position:relative}a[data-astro-cid-jiisrvlr]{color:#fff;text-decoration:none;font-weight:700;transition:color .3s}a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}.has-dropdown[data-astro-cid-jiisrvlr]>.dropdown[data-astro-cid-jiisrvlr]{display:none;position:absolute;top:100%;left:0;background-color:#fff;border-radius:4px;box-shadow:0 2px 5px #0003;min-width:200px;z-index:1000}.has-dropdown[data-astro-cid-jiisrvlr]:hover>.dropdown[data-astro-cid-jiisrvlr]{display:block}.dropdown[data-astro-cid-jiisrvlr] li[data-astro-cid-jiisrvlr]{padding:.5rem 1rem}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]{color:var(--primary-color);display:block;padding:.5rem 0}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}@media (max-width: 768px){.dropdown[data-astro-cid-jiisrvlr]{position:static;box-shadow:none;margin-top:.5rem}}.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{display:flex;list-style:none;gap:2rem}@media (max-width: 768px){.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{flex-direction:column;text-align:center;gap:1rem}}\n"}],"routeData":{"route":"/members/discounts","isIndex":false,"type":"page","pattern":"^\\/members\\/discounts\\/?$","segments":[[{"content":"members","dynamic":false,"spread":false}],[{"content":"discounts","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/members/discounts.astro","pathname":"/members/discounts","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[{"type":"inline","content":".breadcrumb[data-astro-cid-qaanghzh]{padding:1rem;background-color:var(--light-gray);margin-bottom:2rem}.breadcrumb[data-astro-cid-qaanghzh] ol[data-astro-cid-qaanghzh]{list-style:none;display:flex;flex-wrap:wrap;gap:.5rem;max-width:var(--max-width);margin:0 auto}.breadcrumb[data-astro-cid-qaanghzh] li[data-astro-cid-qaanghzh]{display:flex;align-items:center;gap:.5rem}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]{color:var(--primary-color);text-decoration:none}.breadcrumb[data-astro-cid-qaanghzh] a[data-astro-cid-qaanghzh]:hover{text-decoration:underline}.separator[data-astro-cid-qaanghzh]{color:#666}\n.member-resources[data-astro-cid-lgbwzt24]{display:grid;grid-template-columns:repeat(auto-fit,minmax(300px,1fr));gap:2rem;margin-top:2rem}.resource-card[data-astro-cid-lgbwzt24]{background-color:var(--light-gray);padding:2rem;border-radius:5px}.resource-card[data-astro-cid-lgbwzt24] h2[data-astro-cid-lgbwzt24]{color:var(--primary-color);margin-bottom:1rem}.resource-link[data-astro-cid-lgbwzt24]{display:inline-block;margin-top:1rem;color:var(--primary-color);text-decoration:none;font-weight:700}.resource-link[data-astro-cid-lgbwzt24]:hover{color:var(--secondary-color)}\nli[data-astro-cid-jiisrvlr]{position:relative}a[data-astro-cid-jiisrvlr]{color:#fff;text-decoration:none;font-weight:700;transition:color .3s}a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}.has-dropdown[data-astro-cid-jiisrvlr]>.dropdown[data-astro-cid-jiisrvlr]{display:none;position:absolute;top:100%;left:0;background-color:#fff;border-radius:4px;box-shadow:0 2px 5px #0003;min-width:200px;z-index:1000}.has-dropdown[data-astro-cid-jiisrvlr]:hover>.dropdown[data-astro-cid-jiisrvlr]{display:block}.dropdown[data-astro-cid-jiisrvlr] li[data-astro-cid-jiisrvlr]{padding:.5rem 1rem}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]{color:var(--primary-color);display:block;padding:.5rem 0}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}@media (max-width: 768px){.dropdown[data-astro-cid-jiisrvlr]{position:static;box-shadow:none;margin-top:.5rem}}.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{display:flex;list-style:none;gap:2rem}@media (max-width: 768px){.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{flex-direction:column;text-align:center;gap:1rem}}\n"}],"routeData":{"route":"/members","isIndex":true,"type":"page","pattern":"^\\/members\\/?$","segments":[[{"content":"members","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/members/index.astro","pathname":"/members","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[],"routeData":{"route":"/test-post","isIndex":false,"type":"page","pattern":"^\\/test-post\\/?$","segments":[[{"content":"test-post","dynamic":false,"spread":false}]],"params":[],"component":"src/pages/test-post.astro","pathname":"/test-post","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}},{"file":"","links":[],"scripts":[{"type":"external","value":"/_astro/page.B2ohBmLf.js"}],"styles":[{"type":"inline","content":"li[data-astro-cid-jiisrvlr]{position:relative}a[data-astro-cid-jiisrvlr]{color:#fff;text-decoration:none;font-weight:700;transition:color .3s}a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}.has-dropdown[data-astro-cid-jiisrvlr]>.dropdown[data-astro-cid-jiisrvlr]{display:none;position:absolute;top:100%;left:0;background-color:#fff;border-radius:4px;box-shadow:0 2px 5px #0003;min-width:200px;z-index:1000}.has-dropdown[data-astro-cid-jiisrvlr]:hover>.dropdown[data-astro-cid-jiisrvlr]{display:block}.dropdown[data-astro-cid-jiisrvlr] li[data-astro-cid-jiisrvlr]{padding:.5rem 1rem}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]{color:var(--primary-color);display:block;padding:.5rem 0}.dropdown[data-astro-cid-jiisrvlr] a[data-astro-cid-jiisrvlr]:hover{color:var(--secondary-color)}@media (max-width: 768px){.dropdown[data-astro-cid-jiisrvlr]{position:static;box-shadow:none;margin-top:.5rem}}.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{display:flex;list-style:none;gap:2rem}@media (max-width: 768px){.main-nav[data-astro-cid-kkgizz4r] ul[data-astro-cid-kkgizz4r]{flex-direction:column;text-align:center;gap:1rem}}\n.hero[data-astro-cid-v7etr6zh]{background-position:center;background-size:cover;color:#fff;padding:4rem 1rem;text-align:center}.hero-content[data-astro-cid-v7etr6zh]{max-width:var(--max-width);margin:0 auto}.hero[data-astro-cid-v7etr6zh] h1[data-astro-cid-v7etr6zh]{font-size:3rem;margin-bottom:1rem}.hero[data-astro-cid-v7etr6zh] p[data-astro-cid-v7etr6zh]{font-size:1.5rem;margin-bottom:2rem}.cta-button[data-astro-cid-v7etr6zh]{display:inline-block;background-color:var(--secondary-color);color:#fff;padding:1rem 2rem;text-decoration:none;border-radius:5px;font-weight:700;transition:background-color .3s}.cta-button[data-astro-cid-v7etr6zh]:hover{background-color:#c41230}@media (max-width: 768px){.hero[data-astro-cid-v7etr6zh] h1[data-astro-cid-v7etr6zh]{font-size:2rem}.hero[data-astro-cid-v7etr6zh] p[data-astro-cid-v7etr6zh]{font-size:1.2rem}}.hero[data-astro-cid-j7pv25f6]{background:linear-gradient(#003087cc,#003087cc),url(/images/hero-bg.jpg) center/cover;color:#fff;padding:4rem 1rem;text-align:center}.hero-content[data-astro-cid-j7pv25f6]{max-width:var(--max-width);margin:0 auto}.hero[data-astro-cid-j7pv25f6] h1[data-astro-cid-j7pv25f6]{font-size:3rem;margin-bottom:1rem}.hero[data-astro-cid-j7pv25f6] p[data-astro-cid-j7pv25f6]{font-size:1.5rem;margin-bottom:2rem}.cta-button[data-astro-cid-j7pv25f6]{display:inline-block;background-color:var(--secondary-color);color:#fff;padding:1rem 2rem;text-decoration:none;border-radius:5px;font-weight:700;transition:background-color .3s}.cta-button[data-astro-cid-j7pv25f6]:hover{background-color:#c41230}.features[data-astro-cid-j7pv25f6]{max-width:var(--max-width);margin:4rem auto;padding:0 1rem;display:grid;grid-template-columns:repeat(3,1fr);gap:2rem}.feature[data-astro-cid-j7pv25f6]{background-color:var(--light-gray);padding:2rem;border-radius:5px;text-align:center}.feature[data-astro-cid-j7pv25f6] h2[data-astro-cid-j7pv25f6]{color:var(--primary-color);margin-bottom:1rem}.feature[data-astro-cid-j7pv25f6] p[data-astro-cid-j7pv25f6]{margin-bottom:1.5rem}.feature-link[data-astro-cid-j7pv25f6]{color:var(--primary-color);text-decoration:none;font-weight:700}.feature-link[data-astro-cid-j7pv25f6]:hover{color:var(--secondary-color)}@media (max-width: 768px){.features[data-astro-cid-j7pv25f6]{grid-template-columns:1fr}.hero[data-astro-cid-j7pv25f6] h1[data-astro-cid-j7pv25f6]{font-size:2rem}.hero[data-astro-cid-j7pv25f6] p[data-astro-cid-j7pv25f6]{font-size:1.2rem}}\n"}],"routeData":{"route":"/","isIndex":true,"type":"page","pattern":"^\\/$","segments":[],"params":[],"component":"src/pages/index.astro","pathname":"/","prerender":false,"fallbackRoutes":[],"distURL":[],"origin":"project","_meta":{"trailingSlash":"ignore"}}}],"base":"/","trailingSlash":"ignore","compressHTML":true,"componentMetadata":[["/Users/khamudom/Repos/Camden/ufcw152/src/pages/about/index.astro",{"propagation":"none","containsHead":true}],["/Users/khamudom/Repos/Camden/ufcw152/src/pages/about/staff.astro",{"propagation":"none","containsHead":true}],["/Users/khamudom/Repos/Camden/ufcw152/src/pages/index.astro",{"propagation":"none","containsHead":true}],["/Users/khamudom/Repos/Camden/ufcw152/src/pages/members/discounts.astro",{"propagation":"none","containsHead":true}],["/Users/khamudom/Repos/Camden/ufcw152/src/pages/members/index.astro",{"propagation":"none","containsHead":true}]],"renderers":[],"clientDirectives":[["idle","(()=>{var l=(n,t)=>{let i=async()=>{await(await n())()},e=typeof t.value==\"object\"?t.value:void 0,s={timeout:e==null?void 0:e.timeout};\"requestIdleCallback\"in window?window.requestIdleCallback(i,s):setTimeout(i,s.timeout||200)};(self.Astro||(self.Astro={})).idle=l;window.dispatchEvent(new Event(\"astro:idle\"));})();"],["load","(()=>{var e=async t=>{await(await t())()};(self.Astro||(self.Astro={})).load=e;window.dispatchEvent(new Event(\"astro:load\"));})();"],["media","(()=>{var n=(a,t)=>{let i=async()=>{await(await a())()};if(t.value){let e=matchMedia(t.value);e.matches?i():e.addEventListener(\"change\",i,{once:!0})}};(self.Astro||(self.Astro={})).media=n;window.dispatchEvent(new Event(\"astro:media\"));})();"],["only","(()=>{var e=async t=>{await(await t())()};(self.Astro||(self.Astro={})).only=e;window.dispatchEvent(new Event(\"astro:only\"));})();"],["visible","(()=>{var a=(s,i,o)=>{let r=async()=>{await(await s())()},t=typeof i.value==\"object\"?i.value:void 0,c={rootMargin:t==null?void 0:t.rootMargin},n=new IntersectionObserver(e=>{for(let l of e)if(l.isIntersecting){n.disconnect(),r();break}},c);for(let e of o.children)n.observe(e)};(self.Astro||(self.Astro={})).visible=a;window.dispatchEvent(new Event(\"astro:visible\"));})();"]],"entryModules":{"\u0000noop-middleware":"_noop-middleware.mjs","\u0000@astro-page:src/pages/404@_@astro":"pages/404.astro.mjs","\u0000@astro-page:src/pages/about/staff@_@astro":"pages/about/staff.astro.mjs","\u0000@astro-page:src/pages/about/index@_@astro":"pages/about.astro.mjs","\u0000@astro-page:src/pages/blog/backup-slug@_@astro":"pages/blog/backup-slug.astro.mjs","\u0000@astro-page:src/pages/members/discounts@_@astro":"pages/members/discounts.astro.mjs","\u0000@astro-page:src/pages/members/index@_@astro":"pages/members.astro.mjs","\u0000@astro-page:src/pages/test-post@_@astro":"pages/test-post.astro.mjs","\u0000@astro-page:src/pages/index@_@astro":"pages/index.astro.mjs","\u0000@astrojs-ssr-virtual-entry":"entry.mjs","\u0000@astro-renderers":"renderers.mjs","\u0000@astro-page:node_modules/astro/dist/assets/endpoint/generic@_@js":"pages/_image.astro.mjs","\u0000@astrojs-ssr-adapter":"_@astrojs-ssr-adapter.mjs","\u0000@astrojs-manifest":"manifest_DvdMA7Vz.mjs","/Users/khamudom/Repos/Camden/ufcw152/node_modules/astro/dist/assets/services/sharp.js":"chunks/sharp_DGgRtJgq.mjs","astro:scripts/page.js":"_astro/page.B2ohBmLf.js","astro:scripts/before-hydration.js":""},"inlinedScripts":[],"assets":["/favicon.svg","/_astro/page.B2ohBmLf.js","/styles/global.css","/_astro/page.B2ohBmLf.js"],"buildFormat":"directory","checkOrigin":true,"serverIslandNameMap":[],"key":"h5kUqXVXKXmfPofGld1mJ4NxvPev40XC9Ys6+uiHD5I="});
if (manifest.sessionConfig) manifest.sessionConfig.driverModule = null;

export { manifest };
